
Usage
=====

Active Layer
------------
  .. literalinclude:: ../examples/active_layer.py

Add Slate
---------
  .. literalinclude:: ../examples/add_slate.py

Apply Crystallize Filter Action
-------------------------------
  .. literalinclude:: ../examples/apply_crystallize_filter_action.py

Apply Filters
-------------
  .. literalinclude:: ../examples/apply_filters.py

Color
-----
  .. literalinclude:: ../examples/color.py

Compare Colors
--------------
  .. literalinclude:: ../examples/compare_colors.py

Copy And Paste
--------------
  .. literalinclude:: ../examples/copy_and_paste.py

Create Thumbnail
----------------
  .. literalinclude:: ../examples/create_thumbnail.py

Current Tool
------------
  .. literalinclude:: ../examples/current_tool.py

Emboss Action
-------------
  .. literalinclude:: ../examples/emboss_action.py

Eval Javascript
---------------
  .. literalinclude:: ../examples/eval_javascript.py

Fill Selection
--------------
  .. literalinclude:: ../examples/fill_selection.py

Hello World
-----------
  .. literalinclude:: ../examples/hello_world.py

Link Layer
----------
  .. literalinclude:: ../examples/link_layer.py

Load Selection
--------------
  .. literalinclude:: ../examples/load_selection.py

Move To End
-----------
  .. literalinclude:: ../examples/move_to_end.py

New Document
------------
  .. literalinclude:: ../examples/new_document.py

Open Psd
--------
  .. literalinclude:: ../examples/open_psd.py

Photoshop Session
-----------------
  .. literalinclude:: ../examples/photoshop_session.py

Rotate Layer
------------
  .. literalinclude:: ../examples/rotate_layer.py

Selection Stroke
----------------
  .. literalinclude:: ../examples/selection_stroke.py

Session Callback
----------------
  .. literalinclude:: ../examples/session_callback.py

Session Document Duplicate
--------------------------
  .. literalinclude:: ../examples/session_document_duplicate.py

Session Hello World
-------------------
  .. literalinclude:: ../examples/session_hello_world.py

Session New Document
--------------------
  .. literalinclude:: ../examples/session_new_document.py

Session Smart Sharpen
---------------------
  .. literalinclude:: ../examples/session_smart_sharpen.py

Set Active Layer
----------------
  .. literalinclude:: ../examples/set_active_layer.py

Smart Sharpen
-------------
  .. literalinclude:: ../examples/smart_sharpen.py

    